@@ -26,7 +26,7 @@ import hamcrest
 from .internal import (ANY_ARG, OperationList, Method, MockBase, SpyBase,
                        AttributeFactory)
 from .proxy import create_proxy, get_class
-from .matchers import MockExpectInvocation
+from .matchers import MockIsExpectedInvocation
 
 
 __all__ = ['Stub', 'Spy', 'ProxySpy', 'Mock', 'Mimic',
@@ -81,7 +81,7 @@ class Stub(object):
         return None
 
     def __getattr__(self, key):
-        self._add_attr_from_collaborator(key)
+        AttributeFactory.create(self, key)
         return object.__getattribute__(self, key)
 
     def __setattr__hook(self, key, value):
@@ -90,7 +90,7 @@ class Stub(object):
             return
 
         try:
-            self._add_attr_from_collaborator(key)
+            AttributeFactory.create(self, key)
         except AttributeError:
             #  collaborator has not attribute 'key', creaing it ad-hoc
             pass
@@ -98,13 +98,6 @@ class Stub(object):
         # descriptor protocol compliant
         object.__setattr__(self, key, value)
 
-    def _add_attr_from_collaborator(self, key):
-        attr = AttributeFactory.create(self, key)
-        if isinstance(attr, property):
-            setattr(self.__class__, key, attr)
-        else:
-            object.__setattr__(self, key, attr)
-
     def _classname(self):
         name = self._proxy.collaborator_classname()
         return name or self.__class__.__name__
@@ -142,7 +135,7 @@ class ProxySpy(Spy):
 
 class Mock(Spy, MockBase):
     def _prepare_invocation(self, invocation):
-        hamcrest.assert_that(self, MockExpectInvocation(invocation))
+        hamcrest.assert_that(self, MockIsExpectedInvocation(invocation))
         super(Mock, self)._prepare_invocation(invocation)
 
 
@@ -180,13 +173,13 @@ def Mimic(double, collab):
 
 def method_returning(value):
     with Stub() as stub:
-        method = Method(stub, 'unnamed')
+        method = Method(stub, 'orphan')
         method(ANY_ARG).returns(value)
         return method
 
 
 def method_raising(exception):
     with Stub() as stub:
-        method = Method(stub, 'unnamed')
+        method = Method(stub, 'orphan')
         method(ANY_ARG).raises(exception)
         return method
