@@ -179,34 +179,34 @@ class AdhocAttributesTests(TestCase):
 
     def test_add_attribute_for_free_stub(self):
         sut = Stub()
-        sut.foo = 1
+        sut.adhoc = 1
 
     def test_add_attribute_for_verified_stub(self):
         sut = Stub(Collaborator)
-        sut.foo = 1
+        sut.adhoc = 1
 
     def test_add_attribute_for_free_spy(self):
         sut = Spy()
-        sut.foo = 1
+        sut.adhoc = 1
 
     def test_add_attribute_for_verified_spy(self):
         sut = Spy(Collaborator)
-        sut.foo = 1
+        sut.adhoc = 1
 
     def test_add_attribute_for_proxyspy(self):
-        sut = Spy(Collaborator())
-        sut.class_attr = 'other'
+        sut = ProxySpy(Collaborator())
+        sut.adhoc = 1
 
     def test_add_attribute_for_free_mock(self):
         sut = Mock()
-        sut.foo = 1
+        sut.adhoc = 1
 
     def test_add_attribute_for_verified_mock(self):
         sut = Mock(Collaborator)
-        sut.foo = 1
+        sut.adhoc = 1
 
 
-class SpyTests(TestCase):
+class FreeSpyTests(TestCase):
     def setUp(self):
         self.spy = Spy()
 
@@ -342,7 +342,7 @@ class SpyCallsTests(TestCase):
         assert_that(visitor.visitModule.calls[0].args[0].getName(), is_("Module"))
 
 
-class VerifiedSpyTests(TestCase):
+class SpyTests(TestCase):
     def setUp(self):
         self.spy = Spy(Collaborator())
 
@@ -419,18 +419,68 @@ class ProxySpyTests(TestCase):
 
             def store_add(self, value):
                 self.value = value
-                return value + 1
+                return -value
 
         foo = Foo()
         with ProxySpy(foo) as spy:
             spy.store_add(3).returns(1000)
 
-        assert_that(spy.store_add(2), is_(3))
+        assert_that(spy.store_add(2), is_(-2))
         assert_that(foo.value, is_(2))
         assert_that(spy.store_add(3), is_(1000))
         assert_that(foo.value, is_(3))
 
 
+class MockTests(TestCase):
+    def test_with_args(self):
+        mock = Mock()
+        with mock:
+            mock.hello(1)
+            mock.bye(2)
+            mock.bye(3)
+
+        mock.hello(1)
+        mock.bye(2)
+        mock.bye(3)
+
+        assert_that(mock, verify())
+
+    def test_with_several_args(self):
+        mock = Mock()
+        with mock:
+            mock.hello(1, 1)
+            mock.bye(2, 2)
+            mock.bye(3, 3)
+
+        mock.hello(1, 1)
+        mock.bye(2, 2)
+        mock.bye(3, 3)
+
+        assert_that(mock, verify())
+
+    def test_with_kargs(self):
+        mock = Mock()
+        with mock:
+            mock.hello(1, name=1)
+            mock.bye(2, value=2)
+            mock.bye(3, value=3)
+
+        mock.hello(1, name=1)
+        mock.bye(2, value=2)
+        mock.bye(3, value=3)
+
+        assert_that(mock, verify())
+
+    def test_from_instance(self):
+        mock = Mock(Collaborator())
+        with mock:
+            mock.hello()
+
+        mock.hello()
+
+        assert_that(mock, verify())
+
+
 class MockOrderTests(TestCase):
     def setUp(self):
         self.mock = Mock()
@@ -487,16 +537,33 @@ class MockOrderTests(TestCase):
 
         assert_that(self.mock, any_order_verify())
 
+    def test_several_args_with_any_order(self):
+        with self.mock:
+            self.mock.foo(2, 2)
+            self.mock.bar(1)
+            self.mock.foo(1, 1)
+            self.mock.bar(2)
 
-class VerifiedMockTests(TestCase):
-    def test_from_instance(self):
-        mock = Mock(Collaborator())
-        with mock:
-            mock.hello()
+        self.mock.foo(1, 1)
+        self.mock.bar(1)
+        self.mock.foo(2, 2)
+        self.mock.bar(2)
 
-        mock.hello()
+        assert_that(self.mock, any_order_verify())
 
-        assert_that(mock, verify())
+    def test_several_args_with_matcher_any_order(self):
+        with self.mock:
+            self.mock.foo(2, anything())
+            self.mock.bar(1)
+            self.mock.foo(1, anything())
+            self.mock.bar(2)
+
+        self.mock.foo(1, 1)
+        self.mock.bar(1)
+        self.mock.foo(2, 2)
+        self.mock.bar(2)
+
+        assert_that(self.mock, any_order_verify())
 
 
 class DisplayResultsTests(TestCase):
@@ -994,7 +1061,6 @@ class PropertyTests(TestCase):
 
     def test_proxy_spy_get_actual_property(self):
         collaborator = ObjCollaborator()
-        print collaborator.prop
         sut = ProxySpy(collaborator)
         assert_that(sut.prop, is_(1))
 
